@@ -546,6 +546,7 @@ module GObjectIntrospection
     def load_method_info(info, klass, method_name)
       define_method(info, klass, method_name)
       define_equal_style_setter(info, klass, method_name)
+      define_inspect(info, klass, method_name)
     end
 
     def remove_existing_method(klass, method_name)
@@ -591,6 +592,14 @@ module GObjectIntrospection
       end
     end
 
+    def define_inspect(info, klass, method_name)
+      if method_name == "to_s" and info.n_args.zero?
+        klass.__send__(:define_method, "inspect") do ||
+          super().gsub(/\>\z/) {" #{to_s}>"}
+        end
+      end
+    end
+
     def load_function_infos(infos, klass)
       infos.each do |info|
         name = rubyish_method_name(info)
